@@ -19,11 +19,11 @@ export PATH
 if [ "$TASK"x = ""x ] ; then
 	case "$INSTALLER_CD"x in
 		"1"x)
-			TASK=tasks/debian-installer-$CODENAME
+			TASK=debian-installer
 			unset COMPLETE
 			;;
 		"2"x)
-			TASK=tasks/debian-installer+kernel-$CODENAME
+			TASK=debian-installer+kernel
 			unset COMPLETE
 			;;
 		*)
@@ -62,7 +62,9 @@ do
 	echo " ... building the images; using target(s) \"$IMAGETARGET\""
 	make $IMAGETARGET
 
-	make imagesums
+	if [ "$IMAGESUMS"x = 1x ]; then
+		make imagesums
+	fi
 
 	echo "--------------- `date` ---------------"
 done
